<?php

$LANG = array(

'L_ID' 														=> '#',
'L_MENU'													=> 'Menu',
'L_UNKNOWN_ERROR'											=> 'Onbekende fout',
'L_CONFIRM_DELETE'											=> 'Bevestig de verwijdering ?',
'L_SAVE_FILE'												=> 'Sla het bestand op',
'L_SAVE_FILE_SUCCESSFULLY'									=> 'Bestand succesvol opgeslagen',
'L_SAVE_FILE_ERROR'											=> 'Fout bij het ​​opslaan van het bestand voor',
'L_REPLY'													=> 'Antwoord',
'L_REPLY_TO'												=> 'Antwoord',
'L_CANCEL'													=> 'Annuleren',
'L_DELETE'													=> 'Verwijderen',
'L_DELETE_FILE' 				    						=> 'Bestand verwijderen',
'L_DELETE_FOLDER'				   							=> 'Map verwijderen',
'L_DELETE_SUCCESSFUL'										=> 'Succesvol wissen',
'L_DELETE_FILE_ERR'											=> 'Fout bij het verwijderen van het bestand',
'L_RENAME_FILE_SUCCESSFUL'									=> 'Bestand met succes omgedoopt',
'L_RENAME_FILE_ERR'											=> 'Fout bij het verwerken van het bestand',
'L_RENAME_FILE'												=> 'Hernoem bestand',
'L_THUMBNAIL'												=> 'Thumbnail (facultatief)',
'L_THUMBNAIL_SELECTION'										=> 'Selecteer Afbeelding',
'L_THUMBNAIL_TITLE'											=> 'Beeld (facultatief)',
'L_THUMBNAIL_ALT'											=> 'Alternatieve tekst van het beeld (facultatief)',
'L_SAVE_SUCCESSFUL'											=> 'Gegevens succesvol opgeslagen',
'L_SAVE_ERR'												=> 'Fout bij het opslaan van de gegevens',
'L_NO_ENTRY'												=> 'Geen toegang',
'L_ERR_USER_EMPTY'											=> 'Gelieve een gebruikersnaam in te geven',
'L_ERR_PASSWORD_EMPTY'										=> 'Gelieve een wachtwoord in te geven',
'L_ERR_PASSWORD_EMPTY_CONFIRMATION'							=> 'Ongeldig wachtwoord of geen wachtwoord ingegeven',
'L_ERR_INVALID_EMAIL'										=> 'Ongeldig emailadres',
'L_ERR_INVALID_SITE'										=> 'Ongeldig website-adres',
'L_ERR_INVALID_ARTICLE_IDENT'								=> 'Ongeldig artikel-ID',
'L_DEFAULT_NEW_CATEGORY_URL'								=> 'nieuwe-categorie',
'L_DEFAULT_NEW_STATIC_URL'									=> 'nieuwe-pagina',
'L_DEFAULT_NEW_ARTICLE_URL'									=> 'nieuw-artikel',
'L_ARTICLE_SAVE_SUCCESSFUL'									=> 'Artikel succesvol aangemaakt',
'L_ARTICLE_MODIFY_SUCCESSFUL'								=> 'Artikel succesvol bijgewerkt',
'L_ARTICLE_DELETE_SUCCESSFUL'								=> 'Artikel succesvol verwijderd',
'L_ARTICLE_SAVE_ERR'										=> 'Fout bij het opslaan van het artikel',
'L_ARTICLE_DELETE_ERR'										=> 'Fout tijdens het verwijderen van het artikel',
'L_ERR_UNKNOWN_COMMENT'										=> 'De opgevraagde commentaar bestaat niet of niet meer',
'L_COMMENT_SAVE_SUCCESSFUL'									=> 'Commentaar succesvol opgeslagen',
'L_COMMENT_UPDATE_ERR'										=> 'Fout tijdens aanpassen van de commentaar',
'L_COMMENT_DELETE_SUCCESSFUL'								=> 'Commentaar succesvol verwijderd',
'L_COMMENT_DELETE_ERR'										=> 'Er is een fout opgetreden bij het verwijderen van de commentaar',
'L_COMMENT_VALIDATE_SUCCESSFUL'								=> 'Validatie van de commentaar succesvol doorgevoerd',
'L_COMMENT_VALIDATE_ERR'									=> 'Er is een fout opgetreden bij het valideren van de commentaar',
'L_COMMENT_MODERATE_SUCCESSFUL'								=> 'Moderatie succesvol uitgevoerd',
'L_COMMENT_MODERATE_ERR'									=> 'Er is een fout opgetreden tijdens de moderatie',
'L_COMMENT_WRITTEN_BY'										=> 'Geschreven door',
'L_PLXMEDIAS_MEDIAS_FOLDER_ERR'								=> 'Het is onmogelijk de MEDIA folder aan te maken voor deze gebruiker',
'L_PLXMEDIAS_ROOT'											=> 'root-map',
'L_PLXMEDIAS_NEW_FOLDER_ERR'								=> 'Kan de map niet aanmaken',
'L_PLXMEDIAS_NEW_FOLDER_SUCCESSFUL'							=> 'Map succesvol aangemaakt',
'L_PLXMEDIAS_NEW_FOLDER_EXISTS'								=> 'Map bestaat al',
'L_PLXMEDIAS_DEL_FOLDER_ERR'								=> 'Er is een fout opgetreden tijdens het verwijderen van de map',
'L_PLXMEDIAS_DEL_FOLDER_SUCCESSFUL'							=> 'Map succesvol verwijderd',
'L_PLXMEDIAS_WRONG_FILEFORMAT'								=> 'Het bestandstype is niet toegestaan',
'L_PLXMEDIAS_WRONG_FILESIZE'								=> 'Een bestand is groter dan',
'L_PLXMEDIAS_UPLOAD_ERR'									=> 'Fout tijdens het verzenden van een bestand',
'L_PLXMEDIAS_UPLOAD_SUCCESSFUL'								=> 'Bestand dat verstuurd wordt met succes',
'L_PLXMEDIAS_UPLOADS_ERR'									=> 'Fout tijdens het uploaden van bestanden',
'L_PLXMEDIAS_UPLOADS_SUCCESSFUL'							=> 'Bestanden succesvol verzonden',
'L_PLXMEDIAS_DELETE_FILES_SUCCESSFUL'						=> 'Succesvol verwijderde bestanden',
'L_PLXMEDIAS_DELETE_FILES_ERR'								=> 'Fout tijdens het verwijderen van een bestand',
'L_PLXMEDIAS_DELETE_FILE_SUCCESSFUL'						=> 'Bestand met succes verwijderd',
'L_PLXMEDIAS_DELETE_FILE_ERR'								=> 'Fout tijdens het verwijderen van het bestand',
'L_PLXMEDIAS_MOVE_FILES_SUCCESSFUL'							=> 'Bestanden succesvol verplaatst',
'L_PLXMEDIAS_MOVE_FILE_SUCCESSFUL'							=> 'Bestand succesvol verwijderd',
'L_PLXMEDIAS_MOVE_FILES_ERR'								=> 'Er is een fout opgetreden tijdens het verplaatsen van de bestanden',
'L_PLXMEDIAS_MOVE_FILE_ERR'									=> 'Er is een fout opgetreden tijdens het verplaatsen van het bestand',
'L_PLXMEDIAS_MOVE_FOLDER'									=> 'Verplaatsen',
'L_PLXMEDIAS_RECREATE_THUMB_ERR'							=> 'Fout tijdens het maken van de thumbnail',
'L_PLXMEDIAS_RECREATE_THUMBS_ERR'							=> 'Fout bij het ??aanmaken van thumbnail',
'L_PLXMEDIAS_RECREATE_THUMB_SUCCESSFUL'						=> 'Thumbnail succes aangemaakt',
'L_PLXMEDIAS_RECREATE_THUMBS_SUCCESSFUL'					=> 'Thumbnails gemaakt met succes',
'L_DEFAULT_NEW_ARTICLE_TITLE'								=> 'Nieuw Artikel',
'L_ERR_INVALID_PUBLISHING_DATE'								=> 'Ongeldige publicatiedatum',
'L_ERR_UNKNOWN_ARTICLE'										=> 'Het opgevraagde artikel bestaat niet of niet meer !',
'L_ERR_FORBIDDEN_ARTICLE'									=> 'U beschikt niet over de nodige rechten om het artikel te lezen',
'L_BACK_TO_ARTICLES'										=> 'Terug naar lijst met artikels',
'L_ARTICLE_EDITING'											=> 'Artikel wijzigen',
'L_ARTICLE_TITLE'											=> 'Titel',
'L_ARTICLE_LIST_AUTHORS'									=> 'Auteur',
'L_HEADLINE_FIELD'											=> 'Artikelkop (facultatief)',
'L_CONTENT_FIELD'											=> 'Inhoud',
'L_LINK_FIELD'												=> 'Link naar artikel',
'L_LINK_ACCESS'												=> 'Ga naar artikel',
'L_LINK_VIEW'												=> 'zien',
'L_ARTICLE_STATUS'											=> 'Status',
'L_DRAFT'													=> 'Klad',
'L_PUBLISHED'												=> 'Gepublieerd',
'L_AWAITING'												=> 'In afwachting van de validatie',
'L_ARTICLE_DATE'											=> 'Publicatiedatum',
'L_NOW'														=> 'onmiddellijk',
'L_ARTICLE_CATEGORIES'										=> 'Categorie',
'L_CATEGORY_HOME_PAGE'										=> 'Startpagina',
'L_NEW_CATEGORY'											=> 'Nieuwe categorie',
'L_ARTICLE_TAGS_FIELD'										=> 'Sleutelwoorden',
'L_ARTICLE_TAGS_FIELD_TITLE'								=> 'Scheidt de sleutelwoorden door middel van een komma',
'L_ARTICLE_TOGGLER_TITLE'									=> 'Lijst van sleutelwoorden',
'L_NO_TAG'													=> 'Geen tag',
'L_ALLOW_COMMENTS'											=> 'Commentaar toelaten',
'L_ARTICLE_URL_FIELD'										=> 'URL',
'L_ARTICLE_URL_FIELD_TITLE'									=> 'de URL wordt automatisch bij het aanmaken gecr?eerd',
'L_ARTICLE_TEMPLATE_FIELD'									=> 'Template',
'L_ARTICLE_MANAGE_COMMENTS'									=> 'Commentaar beheren',
'L_ARTICLE_MANAGE_COMMENTS_TITLE'							=> 'Commentaren van dit artikel beheren',
'L_ARTICLE_NEW_COMMENT'										=> 'Commentaar ingeven',
'L_ARTICLE_NEW_COMMENT_TITLE'								=> 'Commentaar ingeven voor dit artikel',
'L_ARTICLE_DELETE_CONFIRM'									=> 'Dit artikel daadwerkelijk verwijderen ?',
'L_ARTICLE_PREVIEW_BUTTON'									=> 'Overzicht',
'L_ARTICLE_DRAFT_BUTTON'									=> 'Kladversie opslaan',
'L_ARTICLE_PUBLISHING_BUTTON'								=> 'Posten',
'L_ARTICLE_MODERATE_BUTTON'									=> 'Ter goedkeuring voorleggen',
'L_ARTICLE_OFFLINE_BUTTON'									=> 'Artikel offline plaatsen',
'L_ARTICLE_UPDATE_BUTTON'									=> 'Opslaan',
'L_CATEGORY_ADD_BUTTON'										=> 'Toevoegen',
'L_ARTICLE_META_DESCRIPTION'								=> 'Inhoud meta-tag "description" (optioneel)',
'L_ARTICLE_META_KEYWORDS'									=> 'Inhoud meta-tag "keywords" (optioneel)',
'L_ARTICLE_TITLE_HTMLTAG'									=> 'Title tag inhoud (optioneel)',
'L_ARTICLE_CHAPO_HIDE'										=> 'verstoppen',
'L_ARTICLE_CHAPO_DISPLAY'									=> 'tonen',
'L_ARTICLE'													=> 'artikel',
'L_ARTICLE_ID'												=> 'ID',
'L_AUTH_PAGE_TITLE'											=> 'Aanmeldpagina',
'L_LOGOUT_SUCCESSFUL'										=> 'U bent succesvol aangemeld',
'L_LOGIN_PAGE'												=> 'Aanmelden in administratie',
'L_AUTH_LOGIN_FIELD'										=> 'Uw Login',
'L_AUTH_PASSWORD_FIELD'										=> 'Uw Paswoord',
'L_SUBMIT_BUTTON'											=> 'Verzenden',
'L_ERR_WRONG_PASSWORD'										=> 'Login en/of wachtwoord ongeldig',
'L_POWERED_BY'												=> 'Gegenereerd door <a href="http://www.pluxml.org">PluXml</a>',
'L_ERR_MAXLOGIN'											=> 'Te veel mislukte login<br />Probeer het over% s minuten',
'L_CAT_TITLE'												=> 'Aanmaken en aanpassen van categorie?n',
'L_CAT_LIST_ID'												=> 'ID',
'L_CAT_LIST_ACTIVE'											=> 'Actief',
'L_CAT_LIST_NAME'											=> 'Naam categorie',
'L_CAT_LIST_URL'											=> 'URL',
'L_CAT_LIST_SORT'											=> 'Artikels sorteren',
'L_CAT_LIST_BYPAGE'											=> 'Aantal art/pag',
'L_CAT_LIST_ORDER'											=> 'Volgorde',
'L_CAT_LIST_MENU'											=> 'Menu',
'L_CATEGORY'												=> 'Categorie',
'L_DISPLAY'													=> 'Tonen',
'L_HIDE'													=> 'Onzichtbaar maken',
'L_OPTIONS'													=> 'Opties',
'L_FOR_SELECTION'											=> 'Met geselecteerde...',
'L_CAT_APPLY_BUTTON'										=> 'Categorielijst aanpassen',
'L_CAT_UNKNOWN'												=> 'onbekende categorie',
'L_EDITCAT_PAGE_TITLE'										=> 'Categorie-opties aanpassen',
'L_EDITCAT_DESCRIPTION'										=> 'Beschrijving',
'L_EDITCAT_DISPLAY_HOMEPAGE'								=> 'Toon items in deze categorie op de home page',
'L_EDITCAT_TEMPLATE'										=> 'Template',
'L_EDITCAT_BACK_TO_PAGE'									=> 'Terug naar categorielijst',
'L_EDITCAT_UPDATE'											=> 'De wijzigingen voor deze categorie doorveoeren',
'L_EDITCAT_TITLE_HTMLTAG'									=> 'Title tag inhoud (optioneel)',
'L_EDITCAT_META_DESCRIPTION'								=> 'META-informatie voor deze categorie (optie)',
'L_EDITCAT_META_KEYWORDS'									=> 'META-informatie voor de "keywords" voor deze categorie (optie)',
'L_COMMENT_ORPHAN'											=> 'geen artikel',
'L_COMMENT_ORPHAN_STATUS'									=> 'Niet zichtbaar (Wij raden u aan deze commentaar te verwijderen)',
'L_COMMENT_ARTICLE_LINKED'									=> 'Artikel',
'L_COMMENT_ARTICLE_LINKED_TITLE'							=> 'Artikel van deze commentaar',
'L_COMMENT_OFFLINE'											=> 'offline',
'L_COMMENT_ONLINE'											=> 'online',
'L_COMMENT_ONLINE_TITLE'									=> 'Deze commentaar online bekijken',
'L_BACK_TO_ARTICLE_COMMENTS'								=> 'Terug naar commentaar van dit artikel',
'L_BACK_TO_COMMENTS'										=> 'Terug naar lijst van commentaar',
'L_COMMENT_EDITING'											=> 'Commentaar aanpassen',
'L_COMMENT_AUTHOR_FIELD'									=> 'Auteur',
'L_COMMENT_TYPE_FIELD'										=> 'Type commentaar',
'L_COMMENT_DATE_FIELD'										=> 'Datum en tijd van publicatie',
'L_COMMENT_IP_FIELD'										=> 'Ip',
'L_COMMENT_SITE_FIELD'										=> 'Site',
'L_COMMENT_EMAIL_FIELD'										=> 'E-mail',
'L_COMMENT_STATUS_FIELD'									=> 'Statuut',
'L_COMMENT_LINKED_ARTICLE_FIELD'							=> 'Artikel vastgepind',
'L_COMMENT_ARTICLE_FIELD'									=> 'Commentaar;',
'L_COMMENT_DELETE_CONFIRM'									=> 'Commentaar verwijderen ?',
'L_COMMENT_PUBLISH_BUTTON'									=> 'Publicatie bevestigen',
'L_COMMENT_OFFLINE_BUTTON'									=> 'Offline plaatsen',
'L_COMMENT_ANSWER_BUTTON'									=> 'Antwoorden op commentaar',
'L_COMMENT_UPDATE_BUTTON'									=> 'Aanpassingen doorvoeren',
'L_ERR_ANSWER_UNKNOWN_COMMENT'								=> 'De commentaar bestaat niet of niet meer!',
'L_ERR_ANSWER_OFFLINE_COMMENT'								=> 'Commentaar is offline. Kan niet antwoorden op commentaar !',
'L_ERR_COMMENT_UNKNOWN_ARTICLE'								=> 'Het artikel bestaat niet of niet meer. Onmogelijk te antwoorden !',
'L_ERR_CREATING_COMMENT'									=> 'er is een fout opgetreden tijdens het opslaan van de commentaar',
'L_CREATING_COMMENT_SUCCESSFUL'								=> 'Commentaar plaatsen succesvol',
'L_CREATE_NEW_COMMENT'										=> 'Commentaar schrijven',
'L_COMMENT_SAVE_BUTTON'										=> 'Opslaan',
'L_ARTICLE_COMMENTS_LIST'									=> 'Commentaar van dit artikel (nieuwste commentaar eerst)',
'L_COMMENT_ANSWER_TITLE'									=> 'Antwoorden op deze commentaar',
'L_COMMENT_ANSWER'											=> 'Antwoorden',
'L_COMMENT_NEW_COMMENT_TITLE'								=> 'Nieuwe commentaar schrijven voor dit artikel',
'L_COMMENT_NEW_COMMENT'										=> 'Nieuwe commentaar schrijven',
'L_COMMENTS_ARTICLE_SCOPE'									=> 'Artikel',
'L_COMMENTS_GLOBAL_SCOPE'									=> 'volledige site',
'L_COMMENTS_OFFLINE_LIST'									=> 'Commentaar dat wacht op goedkeuring ',
'L_COMMENTS_LIST_DATE'										=> 'Datum',
'L_COMMENTS_LIST_AUTHOR'									=> 'Auteur',
'L_COMMENTS_LIST_MESSAGE'									=> 'Bericht',
'L_COMMENTS_LIST_ACTION'									=> 'Actie',
'L_COMMENT_EDIT'											=> 'Aanpassen',
'L_COMMENT_EDIT_TITLE'										=> 'Deze commentaar aanpassen',
'L_COMMENT_DELETE'											=> 'Verwijderen',
'L_COMMENT_OFFLINE_FEEDS_TITLE'								=> 'Feed van offline commentaren',
'L_COMMENT_OFFLINE_FEEDS'									=> 'Offline commentaar',
'L_COMMENT_ONLINE_FEEDS_TITLE'								=> 'Feed van online commentaren',
'L_COMMENT_ONLINE_FEEDS'									=> 'Online commentaren',
'L_COMMENTS_PRIVATE_FEEDS'									=> 'Feed prive syndicaties',
'L_COMMENTS_ONLINE_LIST'									=> 'Lijst van gepubliceerde beoordelingen',
'L_COMMENTS_ALL_LIST'										=> 'Reacties Lijst',
'L_COMMENT_SET_ONLINE'										=> 'Neem Online',
'L_COMMENT_SET_OFFLINE'										=> 'Neem Offline',
'L_ARTICLES_FILTER_BUTTON'									=> 'Filteren',
'L_CATEGORIES_TABLE'										=> 'Categorie?n',
'L_SPECIFIC_CATEGORIES_TABLE'								=> 'Specifieke locatie',
'L_ALL_ARTICLES_CATEGORIES_TABLE'							=> 'Alle artikels',
'L_ARTICLES_LIST'											=> 'Lijst met artikels',
'L_ARTICLE_LIST_DATE'										=> 'Datum',
'L_ARTICLE_LIST_TITLE'										=> 'Titel',
'L_ARTICLE_LIST_CATEGORIES'									=> 'Categorie',
'L_ARTICLE_LIST_NBCOMS'										=> 'Aantal comm.',
'L_ARTICLE_LIST_AUTHOR'										=> 'Auteur',
'L_ARTICLE_LIST_ACTION'										=> 'Actie',
'L_CATEGORY_HOME'											=> 'Home',
'L_CATEGORY_DRAFT'											=> 'Klad',
'L_ARTICLE_VIEW_TITLE'										=> 'Bekijk het artikel op de site',
'L_ARTICLE_EDIT'											=> 'Aanpassen',
'L_ARTICLE_EDIT_TITLE'										=> 'Artikel aanpassen',
'L_NEW_COMMENTS_TITLE'										=> 'Commentaar die op goedkeuring wacht',
'L_VALIDATED_COMMENTS_TITLE'								=> 'Geplubliceerde commentaar',
'L_NO_ARTICLE'												=> 'Geen artikel',
'L_SEARCH'													=> 'Zoek',
'L_SEARCH_PLACEHOLDER'										=> 'artikel-ID of titel',
'L_ARTICLES_ALL_CATEGORIES'									=> 'Alle categorie?n ...',
'L_ALL'														=> 'Alle',
'L_ALL_PUBLISHED'											=> 'Gepubliceerd',
'L_ALL_DRAFTS'												=> 'Concepten',
'L_ALL_AWAITING_MODERATION'									=> 'In afwachting van de validatie',
'L_MEDIAS_DELETE_FOLDER'									=> 'Map verwijderen',
'L_MEDIAS_DELETE_FOLDER_CONFIRM'							=> 'Map en inhoud van de map verwijderen %s ?',
'L_MEDIAS_NO_FILE'											=> 'Geen bestand',
'L_MEDIAS_FILENAME'											=> 'Naam bastand',
'L_MEDIAS_ADD_FILE'											=> 'Bestand toevoegne',
'L_MEDIAS_BACK'												=> 'Terug',
'L_MEDIAS_TITLE'											=> 'Media beheren',
'L_MEDIAS_IMAGES'											=> 'Afbeeldingen',
'L_MEDIAS_DOCUMENTS'										=> 'Documenten',
'L_MEDIAS_CREATE_FOLDER'									=> 'Map aanmaken',
'L_MEDIAS_SUBMIT_FILE'										=> 'Versturen',
'L_MEDIAS_MAX_UPOLAD_FILE'									=> 'Maximale grootte bestand',
'L_MEDIAS_MAX_POST_SIZE'									=> 'Maximale gegevensgrootte',
'L_MEDIAS_DIRECTORY'										=> 'Locatie',
'L_MEDIAS_FOLDER'											=> 'Bestand',
'L_MEDIAS_NEW_FOLDER'										=> 'Nieuwe map',
'L_MEDIAS_FILESIZE'											=> 'Maat',
'L_MEDIAS_DATE'												=> 'Datum',
'L_MEDIAS_DIMENSIONS'										=> 'Dimensies',
'L_MEDIAS_RESIZE'											=> 'Afbeeldinggrootte',
'L_MEDIAS_RESIZE_NO'										=> 'Oorspronkelijk formaat',
'L_MEDIAS_THUMBS'											=> 'Maak thumbnails',
'L_MEDIAS_THUMBS_NONE'										=> 'Geen miniatuur',
'L_MEDIAS_MODIFY'											=> 'Bewerken',
'L_MEDIAS_THUMB'											=> 'Thumbnail',
'L_MEDIAS_EXTENSION'										=> 'Uitbreiding',
'L_MEDIAS_ADD'												=> 'Toevoegen',
'L_MEDIAS_ALIGNMENT'										=> 'Uitlijning',
'L_MEDIAS_ALIGN_NONE'										=> 'Geen',
'L_MEDIAS_ALIGN_LEFT'										=> 'Links',
'L_MEDIAS_ALIGN_CENTER'										=> 'Centrum',
'L_MEDIAS_ALIGN_RIGHT'										=> 'Rechts',
'L_MEDIAS_RECREATE_THUMB'									=> 'Opnieuw thumbnail',
'L_MEDIAS_LINK_COPYCLP'                                     => 'Kopieer Link naar klembord',
'L_MEDIAS_LINK_COPYCLP_ERR'                                 => 'Niet in staat om de link te kopiëren naar het klembord',
'L_MEDIAS_LINK_COPYCLP_DONE'                                => 'Koppeling gekopieerd',
'L_MEDIAS_NEW_NAME'											=> 'Nieuwe naam',
'L_MEDIAS_RENAME'											=> 'Andere naam geven',
'L_SORT_ASCENDING_DATE'										=> 'datum oplopend',
'L_SORT_DESCENDING_DATE'									=> 'datum aflopend',
'L_SORT_ALPHABETICAL'										=> 'alfabetisch',
'L_SORT_RANDOM'												=> 'onzeker',
'L_OK'														=> 'Ok',
'L_YES'														=> 'Ja',
'L_NO'														=> 'Neen',
'L_NONE1'													=> 'geen',
'L_NONE2'													=> 'geen',
'L_CONFIG_VIEW_FIELD'										=> 'Options d\'affichage',
'L_CONFIG_VIEW_SKIN_SELECT'									=> 'Keuze van layout',
'L_CONFIG_VIEW_FILES_EDIT_TITLE'							=> 'Layout-bestanden aanpassen',
'L_CONFIG_VIEW_FILES_EDIT'									=> 'Layout-bestanden editeren',
'L_CONFIG_VIEW_SORT'										=> 'Artikels sorteren',
'L_CONFIG_VIEW_BYPAGE'										=> 'Aantal artikels per pagina',
'L_CONFIG_VIEW_BYPAGE_ARCHIVES'								=> 'Aantal artikels par pagina in archief',
'L_CONFIG_VIEW_BYPAGE_TAGS'									=> 'Aantal artikels per pagina in tags',
'L_CONFIG_VIEW_BYPAGE_ADMIN'								=> 'Aantal artikels per pagina in administratie-gedeelte',
'L_CONFIG_VIEW_SORT_COMS'									=> 'Commentaar sorteren',
'L_CONFIG_VIEW_BYPAGE_ADMIN_COMS'							=> 'Aantal commentaren per pagina in administratie-gedeelte',
'L_CONFIG_VIEW_IMAGES'										=> 'Beeldformaat (breedte x hoogte)',
'L_CONFIG_VIEW_THUMBS'										=> 'Grootte thumbnails (breedte x hoogte)',
'L_CONFIG_VIEW_HOMESTATIC'									=> 'een statische pagina als verwelkomingspagina gebruiken',
'L_CONFIG_VIEW_HOMESTATIC_ACTIVE'							=> 'Opgelet. Deze pagina is niet actief',
'L_CONFIG_VIEW_PLUXML_RESSOURCES'							=> 'Nieuwe layouts downloaden op <a href="http://ressources.pluxml.org">ressources.pluxml.org</a>.',
'L_CONFIG_VIEW_BYPAGE_FEEDS'								=> 'Aantal artikels/commentaar in RSS feed',
'L_CONFIG_VIEW_FEEDS_HEADLINE'								=> 'Korte samenvatting in RSS feed opnemen',
'L_CONFIG_VIEW_FEEDS_HEADLINE_HELP'							=> 'Indien samenvatting leeg is zal artikelinhoud getoond worden',
'L_CONFIG_VIEW_FEEDS_FOOTER'								=> 'Tekskt die getoond zal worden onder elke RSS feed',
'L_CONFIG_VIEW_UPDATE'										=> 'Pas de veranderingen toe',
'L_CONFIG_VIEW_DISPLAY_EMPTY_CAT'							=> 'Toon categorieën zonder artikel',
'L_CONFIG_HOMETEMPLATE'										=> 'Template van de homepage',
'L_CONFIG_ADVANCED_DESC'									=> 'Geavanceerde configuratie',
'L_CONFIG_ADVANCED_URL_REWRITE'								=> 'herschrijven van URLs aanzetten',
'L_CONFIG_ADVANCED_URL_REWRITE_ALERT'						=> 'Opgepast. Er bestaat al een .htaccess bestand in de root van uw installatie. Door het inschakelen van URL herschrijven dit bestand zal worden gewijzigd',
'L_CONFIG_ADVANCED_GZIP'									=> 'GZIP compressie activeren',
'L_CONFIG_ADVANCED_GZIP_HELP'								=> 'Compressie activeren zal het verbruik van uw bandbreedte naar beneden halen, maar kan uw processor wat meer belasten',
'L_CONFIG_ADVANCED_CAPCHA'									=> 'Anti-spam CAPTCHA gebruiken',
'L_CONFIG_ADVANCED_ADMIN_KEY'								=> 'Code voor versleuteling gegevens (Prive URLs)',
'L_CONFIG_ADVANCED_KEY_HELP'								=> 'Maak dit veld leeg om een nieuwe sleutel te genereren',
'L_CONFIG_ADVANCED_USERFOLDERS'								=> 'Gebruik verschillende media map voor elke gebruiker',
'L_HELP_SLASH_END'											=> 'vergeet de slash niet op het einde',
'L_CONFIG_ADVANCED_MEDIAS_FOLDER'							=> 'Locatie media (map)',
'L_CONFIG_ADVANCED_ARTS_FOLDER'								=> 'Locatie artikels (map)',
'L_CONFIG_ADVANCED_COMS_FOLDER'								=> 'Locatie commentaar (map)',
'L_CONFIG_ADVANCED_STATS_FOLDER'							=> 'Locatie statische paginas (map)',
'L_CONFIG_ADVANCED_THEMES_FOLDER'							=> 'Locatie van onderwerpen (map)',
'L_CONFIG_ADVANCED_PLUGINS_FOLDER'							=> 'Locatie van de plugins (map)',
'L_CONFIG_ADVANCED_CONFIG_FOLDER'							=> 'Locatie van de configuratie-bestanden (map)',
'L_CONFIG_ADVANCED_UPDATE'									=> 'Aanpassingen doorvoeren',
'L_CONFIG_CUSTOM_CSSADMIN_PATH'								=> 'Locatie en de naam van aangepaste css-bestand van de administratie gebied (optioneel)',
'L_CONFIG_BASE_CONFIG_TITLE'								=> 'Basisconfiguratie',
'L_CONFIG_BASE_SITE_TITLE'									=> 'Titel van de site',
'L_CONFIG_BASE_SITE_SLOGAN'									=> 'Ondertitel van de site',
'L_CONFIG_BASE_URL_HELP'									=> 'Vergeet de slech niet op het einde',
'L_CONFIG_BASE_DEFAULT_LANG'								=> 'Standaardtaal',
'L_CONFIG_BASE_TIMEZONE'									=> 'Tijdzone',
'L_CONFIG_BASE_ALLOW_COMMENTS'								=> 'Commentaar toelaten',
'L_CONFIG_BASE_MODERATE_COMMENTS'							=> 'Commentaar modereren bij creatie',
'L_CONFIG_BASE_MODERATE_ARTICLES'							=> 'De artikelen voor de profielen Redacteur en Uitgever matigen',
'L_CONFIG_BASE_UPDATE'										=> 'Basisconfiguratie aanpassen',
'L_CONFIG_META_DESCRIPTION'									=> 'META-tag "descriptie" van de site (optioneel)',
'L_CONFIG_META_KEYWORDS'									=> 'META-tag "keywords" van de site (optioneel)',
'L_CONFIG_EDITTPL_ERROR_NOTHEME'							=> 'Layout bestaat niet !',
'L_CONFIG_EDITTPL_TITLE'									=> 'Layout aanpassen',
'L_CONFIG_EDITTPL_SELECT_FILE'								=> 'Keuze aan te passen bestand :',
'L_CONFIG_EDITTPL_LOAD'										=> 'Laden',
'L_CONFIG_INFOS_TITLE'										=> 'Informatie over uw PluXml-installatie',
'L_CONFIG_INFOS_DESCRIPTION'								=> 'Deze informatie kan handig zijn om eventuele problemen van uw installatie te vinden',
'L_CONFIG_INFOS_NB_CATS'									=> 'aantal categorie?n :',
'L_CONFIG_INFOS_NB_STATICS'									=> 'aantal statische paginas :',
'L_CONFIG_INFOS_WRITER'										=> 'Naam redacteur :',
'L_PLUXML_CHECK_VERSION'									=> 'Uw huidige versie van PluXml wordt vergeleken met de nieuwste op de website van PluXML',
'L_PLUXML_UPDATE_UNAVAILABLE'								=> 'Onmogelijk om updates te vinden zolang de optie \'allow_url_fopen\' gedesactiveerd is op dit systeem',
'L_PLUXML_UPDATE_ERR'										=> 'De verificatie van updates kon om een onbekende reden niet doorgevoerd worden',
'L_PLUXML_UPTODATE'											=> 'U beschikt over de laatste versie van PluXml',
'L_PLUXML_UPDATE_AVAILABLE'									=> 'Er is een nieuwe versie van PluXml beschikbaar ! U kan ze downloaden op ',
'L_CONFIG_USERS_TITLE'										=> 'Gebruikers beheren',
'L_CONFIG_USER'												=> 'Gebruiker',
'L_CONFIG_USERS_ID'											=> 'Gebruikersnummer',
'L_CONFIG_USERS_ACTIVE'										=> 'Actief',
'L_CONFIG_USERS_ACTION'										=> 'Actie',
'L_CONFIG_USERS_NEW'										=> 'Nieuwe gebruiker',
'L_CONFIG_USERS_UPDATE'										=> 'Lijst van gebruikers aanpassen',
'L_ERR_LOGIN_ALREADY_EXISTS'								=> 'Login ID al in gebruik',
'L_ERR_USERNAME_ALREADY_EXISTS'								=> 'Gebruikersnaam al in gebruik',
'L_ERR_CATEGORY_ALREADY_EXISTS'								=> 'Categorie naam al in gebruik',
'L_ERR_STATIC_ALREADY_EXISTS'								=> 'Zoals reeds gebruikt',
'L_BACK_TO_PLUGINS'											=> 'Terug naar Plugin-pagina',
'L_NO_PLUGIN'												=> 'Geen plugin',
'L_PLUGIN_NO_CONFIG'										=> 'Plugin niet geconfigureerd',
'L_PLUGINS_CSS'												=> 'CSS-code',
'L_PLUGINS_CSS_TITLE'										=> 'Bewerk de CSS-code van de plugin',
'L_CONTENT_FIELD_FRONTEND'									=> 'Css-bestand inhoud website',
'L_CONTENT_FIELD_BACKEND'									=> 'Css-bestand inhoud administrator',
'L_PLUGINS_TITLE'											=> 'Plugins beheren',
'L_PLUGINS_VERSION'											=> 'Versie',
'L_PLUGINS_AUTHOR'											=> 'Auteur',
'L_PLUGINS_ACTIVATE'										=> 'Activeren',
'L_PLUGINS_DEACTIVATE'										=> 'Desactiveren',
'L_PLUGINS_DELETE'											=> 'Verwijderen',
'L_PLUGINS_DELETE_ERROR'									=> 'Er is een fout opgetreden bij het verwijderen',
'L_PLUGINS_DELETE_SUCCESSFUL'								=> 'Verwijdering succesvl doorgevoerd',
'L_PLUGINS_CONFIG'											=> 'Configuratie',
'L_PLUGINS_CONFIG_TITLE'									=> 'Configuratie van de plugin',
'L_PLUGINS_HELP'											=> 'Helpen',
'L_PLUGINS_HELP_TITLE'										=> 'Zie Met behulp van de plugin',
'L_PLUGINS_REQUIREMENTS'									=> 'Benodigdheden',
'L_PLUGINS_REQUIREMENTS_HELP'								=> 'Lijst van beschikbare en actieve plugins voor deze plugin',
'L_PLUGINS_REQUIREMENTS_NONE'								=> 'Geen',
'L_PLUGINS_ALPHA_SORT'										=> 'Alfabetisch sorteren plugins',
'L_PLUGINS_LOADING_SORT'									=> 'Laden om',
'L_PLUGINS_ACTION'											=> 'Actie',
'L_PLUGINS_APPLY_BUTTON'									=> 'De lijst met plugins',
'L_PLUGINS_ACTIVE_LIST'										=> 'Actieve plugins',
'L_PLUGINS_INACTIVE_LIST'									=> 'Inactief plugins',
'L_PROFIL_EDIT_TITLE'										=> 'Uw profiel aanpassen',
'L_PROFIL'													=> 'Profiel',
'L_PROFIL_LOGIN'											=> 'Kies uw loginnaam',
'L_PROFIL_USER'												=> 'Kies uw gebruikersnaam',
'L_PROFIL_MAIL'												=> 'Emailadres',
'L_PROFIL_ADMIN_LANG'										=> 'Taal van administratiegedeelte',
'L_PROFIL_INFOS'											=> 'Informatie',
'L_PROFIL_UPDATE'											=> 'Uw profiel aanpassen',
'L_PROFIL_CHANGE_PASSWORD'									=> 'Wachtwoord veranderen',
'L_PROFIL_PASSWORD'											=> 'Wachtwoord',
'L_PROFIL_CONFIRM_PASSWORD'									=> 'Wachtwoord bevestigen',
'L_PROFIL_UPDATE_PASSWORD'									=> 'Wachtwoord veranderen',
'L_STATIC_BACK_TO_PAGE'										=> 'Terug naar lijst van statische paginas',
'L_STATIC_UNKNOWN_PAGE'										=> 'Deze statische pagina bestaat niet of niet meer !',
'L_STATIC_TITLE'											=> 'Bron van statische pagina aanpassen',
'L_STATIC_VIEW_PAGE'										=> 'Bekijk de pagina',
'L_STATIC_ON_SITE'											=> 'op de site',
'L_STATIC_UPDATE'											=> 'Statische pagina opslaan',
'L_STATIC_TITLE_HTMLTAG'									=> 'Title tag inhoud (optioneel)',
'L_STATIC_META_DESCRIPTION'									=> 'META-tag "description" voor deze statische pagina (optioneel)',
'L_STATIC_META_KEYWORDS'									=> 'META-tag "keywords" voor deze statische pagina (optioneel)',
'L_STATICS_PAGE_TITLE'										=> 'Aanmaken en aanpassen van statische paginas',
'L_STATICS_ID'												=> 'Naam pagina',
'L_STATICS_GROUP'											=> 'Groep',
'L_STATICS_TITLE'											=> 'Titel',
'L_STATICS_URL'												=> 'URL',
'L_STATICS_ACTIVE'											=> 'Actief',
'L_STATICS_ORDER'											=> 'Volgorde',
'L_STATICS_MENU'											=> 'Menu',
'L_STATICS_ACTION'											=> 'Actie',
'L_STATICS_TEMPLATE_FIELD'									=> 'Layout',
'L_STATICS_PAGE_HOME'										=> 'Instellen als homepage',
'L_STATICS_HOME_PAGE'										=> 'Startpagina',
'L_PAGE'													=> 'Pagina',
'L_VIEW'													=> 'Bekijken',
'L_STATICS_SRC_TITLE'										=> 'Bron van deze pagina aanpassen',
'L_STATICS_SRC'												=> 'Aanpassen',
'L_STATICS_NEW_PAGE'										=> 'Nieuwe pagina',
'L_STATICS_UPDATE'											=> 'Lijst van statische paginas bewerken',
'L_PROFIL_ADMIN'											=> 'Administrateur',
'L_PROFIL_MANAGER'											=> 'Beheerder',
'L_PROFIL_MODERATOR'										=> 'Moderator',
'L_PROFIL_EDITOR'											=> 'Editeur',
'L_PROFIL_WRITER'											=> 'Redacteur',
'L_ADMIN'													=> 'Administratie',
'L_LOGIN'													=> 'Aangemeld als',
'L_ADMIN_LOGOUT'											=> 'Afmelden',
'L_ADMIN_LOGOUT_TITLE'										=> 'Sluit adminstratie-sessie',
'L_BACK_TO_SITE'											=> 'Home',
'L_BACK_TO_SITE_TITLE'										=> 'Terug naar home',
'L_BACK_TO_BLOG'											=> 'Blog',
'L_BACK_TO_BLOG_TITLE'										=> 'Terug naar blog',
'L_MENU_ARTICLES'											=> 'Artikels',
'L_MENU_ARTICLES_TITLE'										=> 'Lijst en aanpassingen artikels',
'L_MENU_NEW_ARTICLES'										=> 'Nieuw artikel',
'L_MENU_NEW_ARTICLES_TITLE'									=> 'Nieuw artikel',
'L_MENU_STATICS_TITLE'										=> 'Lijst en aanpassingen statische paginas',
'L_MENU_STATICS'											=> 'Statische paginas',
'L_MENU_COMMENTS_TITLE'										=> 'Lijst en aanpassingen commentaren',
'L_MENU_COMMENTS'											=> 'Commentaren',
'L_MENU_MEDIAS_TITLE'										=> 'Media uploaden en toevoegen',
'L_MENU_MEDIAS'												=> 'Media',
'L_MENU_CATEGORIES_TITLE'									=> 'Categorie?n aanmaken, beheren, verwijderen',
'L_MENU_CATEGORIES'											=> 'Categorie?n',
'L_MENU_CONFIG_TITLE'										=> 'PluXml configureren',
'L_MENU_CONFIG'												=> 'Parameters',
'L_MENU_PROFIL_TITLE'										=> 'Uw gebruikersprofiel beheren',
'L_MENU_PROFIL'												=> 'Profiel',
'L_WARNING_INSTALLATION_FILE'								=> 'het bestand install.php is nog aanwezig in de basismap van uw PluXml.<br />Om veiligheidsredenen raden wij u aan dit bestand te <a class="lnkdelete" href="?del=install">verwijderen</a> of te hernoemen.',
'L_USER_UNKNOWN'											=> 'Onbekende gebruiker',
'L_USER_LANG'												=> 'Gebruikte taal in adminstratief gedeelte',
'L_USER_MAIL'												=> 'Emailadres',
'L_USER_INFOS'												=> 'Informatie',
'L_USER_UPDATE'												=> 'Deze gebruiker aanpassen',
'L_USER_PAGE_TITLE'											=> 'Gebruikersopties aanpassen',
'L_USER_BACK_TO_PAGE'										=> 'Terug naar gebruikerslijst',
'L_MENU_CONFIG_BASE_TITLE'									=> 'Uw PluXml basisconfiguratie bewerken',
'L_MENU_CONFIG_BASE'										=> 'Basisconfiguratie',
'L_MENU_CONFIG_VIEW_TITLE'									=> 'PluXml Scherminstellingen',
'L_MENU_CONFIG_VIEW'										=> 'Opties scherminstelling',
'L_MENU_CONFIG_USERS_TITLE'									=> 'Uw PluXml gebruikers beheren',
'L_MENU_CONFIG_USERS'										=> 'Gebruikers',
'L_MENU_CONFIG_ADVANCED_TITLE'								=> 'Geavanceerde opties van PluXml bewerken',
'L_MENU_CONFIG_ADVANCED'									=> 'Geavanceerde opties',
'L_MENU_CONFIG_INFOS_TITLE'									=> 'Informatie over uw PluXml-installatie',
'L_MENU_CONFIG_INFOS'										=> 'Informatie',
'L_MENU_CONFIG_PLUGINS_TITLE'								=> 'Plugins beheren',
'L_MENU_CONFIG_PLUGINS'										=> 'Plugins',
'L_ERR_URL_ALREADY_EXISTS'									=> 'Url al in gebruik. Moet u de waarde van het veld \'Url\'',
'L_THEMES'													=> 'Thema\'s',
'L_THEMES_TITLE'											=> 'Het beheren van thema\'s',
'L_HELP'													=> 'Hulp',
'L_HELP_TITLE'												=> 'Zie hulp',
'L_BACK_TO_THEMES'											=> 'Terug naar de onderwerpen van de pagina',
'L_CONFIG_THEME_UPDATE'										=> 'Change Theme',
'L_ERR_INVALID_DATE_CREATION'								=> 'Ongeldige aanmaakdatum',
'L_ERR_INVALID_DATE_UPDATE'									=> 'Ongeldige datum bijgewerkt',
);
?>